@@ -85,7 +85,9 @@ class ApolloClient(object):
             secret='',
             start_hot_update=True,
             change_listener=None,
-            cycle_time=2
+            cycle_time=2,
+            timeout=(5, 10),
+            pull_timeout=(5, 60)
     ):
 
         # 核心路由参数
@@ -105,12 +107,13 @@ class ApolloClient(object):
         self._cache = {}
         self._no_key = {}
         self._hash = {}
-        self._pull_timeout = 75
+        self._pull_timeout = pull_timeout
         self._cache_file_path = os.path.expanduser('~') + '/cache/'
         self._long_poll_thread = None
         self._change_listener = change_listener  # "add" "delete" "update"
         self._notification_map = {'application': -1}
         self.last_release_key = None
+        self.timeout = timeout
         # 私有启动方法
         self._path_checker()
         if start_hot_update:
@@ -125,7 +128,7 @@ class ApolloClient(object):
         url = '{}/configs/{}/{}/{}?releaseKey={}&ip={}'.format(self.config_url, self.app_id, self.cluster, namespace,
                                                                "", self.ip)
         try:
-            code, body = http_request(url, timeout=3, headers=self._signHeaders(url))
+            code, body = http_request(url, timeout=self.timeout, headers=self._signHeaders(url))
             if code == 200:
                 data = json.loads(body)
                 data = data["configurations"]
@@ -321,7 +324,7 @@ class ApolloClient(object):
         url = '{}/configs/{}/{}/{}?ip={}'.format(self.config_url, self.app_id, self.cluster, namespace,
                                                  self.ip)
         try:
-            code, body = http_request(url, timeout=3, headers=self._signHeaders(url))
+            code, body = http_request(url, timeout=self.timeout, headers=self._signHeaders(url))
             if code == 200:
                 data = json.loads(body)
                 if self.last_release_key == data["releaseKey"]:
